@@ -58,6 +58,7 @@ void ActionManager::setupAction(MainWindow *mainWindow)
     CREATE_NEW_ACTION(mainWindow, actionHorizontalFlip);
     CREATE_NEW_ACTION(mainWindow, actionFitInView);
     CREATE_NEW_ACTION(mainWindow, actionFitByWidth);
+    CREATE_NEW_ACTION(mainWindow, actionFitLongImage);
     CREATE_NEW_THEMEICON_ACTION(mainWindow, actionCopyPixmap, edit-copy);
     CREATE_NEW_ACTION(mainWindow, actionCopyFilePath);
     CREATE_NEW_THEMEICON_ACTION(mainWindow, actionPaste, edit-paste);
@@ -101,6 +102,7 @@ void ActionManager::retranslateUi(MainWindow *mainWindow)
     actionHorizontalFlip->setText(QCoreApplication::translate("MainWindow", "Flip &Horizontally", nullptr));
     actionFitInView->setText(QCoreApplication::translate("MainWindow", "Fit to view", nullptr));
     actionFitByWidth->setText(QCoreApplication::translate("MainWindow", "Fit to width", nullptr));
+    actionFitLongImage->setText(QCoreApplication::translate("MainWindow", "Fit long image", nullptr));
     actionCopyPixmap->setText(QCoreApplication::translate("MainWindow", "Copy P&ixmap", nullptr));
     actionCopyFilePath->setText(QCoreApplication::translate("MainWindow", "Copy &File Path", nullptr));
     actionPaste->setText(QCoreApplication::translate("MainWindow", "&Paste", nullptr));
