@@ -222,7 +222,7 @@ void MainWindow::adjustWindowSizeBySceneRect()
 
     if (m_graphicsView->scaleFactor() < 1 || size().expandedTo(sceneSizeWithMargins) != size()) {
         // if it scaled down by the resize policy:
-        QSize screenSize = window()->screen()->availableSize();
+        QSize screenSize = qApp->screenAt(QCursor::pos())->availableSize();
         if (screenSize.expandedTo(sceneSize) == screenSize) {
             // we can show the picture by increase the window size.
             QSize finalSize = (screenSize.expandedTo(sceneSizeWithMargins) == screenSize) ?
@@ -584,7 +584,7 @@ void MainWindow::centerWindow()
             Qt::LeftToRight,
             Qt::AlignCenter,
             this->size(),
-            window()->screen()->availableGeometry()
+            qApp->screenAt(QCursor::pos())->availableGeometry()
         )
     );
 }
@@ -700,6 +700,7 @@ void MainWindow::on_actionActualSize_triggered()
 {
     m_graphicsView->resetScale();
     m_graphicsView->setEnableAutoFitInView(false);
+    m_graphicsView->setLongImageMode(false);
 }
 
 void MainWindow::on_actionToggleMaximize_triggered()
@@ -728,6 +729,7 @@ void MainWindow::on_actionFitInView_triggered()
 {
     m_graphicsView->fitInView(m_gv->sceneRect(), Qt::KeepAspectRatio);
     m_graphicsView->setEnableAutoFitInView(m_graphicsView->scaleFactor() <= 1);
+    m_graphicsView->setLongImageMode(false);
 }
 
 void MainWindow::on_actionFitByWidth_triggered()
@@ -735,6 +737,12 @@ void MainWindow::on_actionFitByWidth_triggered()
     m_graphicsView->fitByOrientation();
 }
 
+void MainWindow::on_actionFitLongImage_triggered()
+{
+    m_graphicsView->setLongImageMode(true);
+    m_graphicsView->fitLongImage();
+}
+
 void MainWindow::on_actionCopyPixmap_triggered()
 {
     QClipboard *cb = QApplication::clipboard();
@@ -813,14 +821,12 @@ void MainWindow::on_actionRotateClockwise_triggered()
 {
     m_graphicsView->rotateView();
     m_graphicsView->displayScene();
-    m_gv->setVisible(false);
 }
 
 void MainWindow::on_actionRotateCounterClockwise_triggered()
 {
     m_graphicsView->rotateView(false);
     m_graphicsView->displayScene();
-    m_gv->setVisible(false);
 }
 
 void MainWindow::on_actionPrevPicture_triggered()
