@@ -23,6 +23,8 @@ SettingsDialog::SettingsDialog(QWidget *parent)
     , m_useBuiltInCloseAnimation(new QCheckBox)
     , m_useLightCheckerboard(new QCheckBox)
     , m_loopGallery(new QCheckBox)
+    , m_autoLongImageMode(new QCheckBox)
+    , m_svgTiny12Only(new QCheckBox)
     , m_doubleClickBehavior(new QComboBox)
     , m_mouseWheelBehavior(new QComboBox)
     , m_initWindowSizeBehavior(new QComboBox)
@@ -123,6 +125,8 @@ SettingsDialog::SettingsDialog(QWidget *parent)
     settingsForm->addRow(tr("Use built-in close window animation"), m_useBuiltInCloseAnimation);
     settingsForm->addRow(tr("Use light-color checkerboard"), m_useLightCheckerboard);
     settingsForm->addRow(tr("Loop the loaded gallery"), m_loopGallery);
+    settingsForm->addRow(tr("Auto long image mode"), m_autoLongImageMode);
+    settingsForm->addRow(tr("Limit SVG support to SVG Tiny 1.2"), m_svgTiny12Only);
     settingsForm->addRow(tr("Double-click behavior"), m_doubleClickBehavior);
     settingsForm->addRow(tr("Mouse wheel behavior"), m_mouseWheelBehavior);
     settingsForm->addRow(tr("Default window size"), m_initWindowSizeBehavior);
@@ -132,6 +136,8 @@ SettingsDialog::SettingsDialog(QWidget *parent)
     m_useBuiltInCloseAnimation->setChecked(Settings::instance()->useBuiltInCloseAnimation());
     m_useLightCheckerboard->setChecked(Settings::instance()->useLightCheckerboard());
     m_loopGallery->setChecked(Settings::instance()->loopGallery());
+    m_autoLongImageMode->setChecked(Settings::instance()->autoLongImageMode());
+    m_svgTiny12Only->setChecked(Settings::instance()->svgTiny12Only());
     m_doubleClickBehavior->setModel(new QStringListModel(dcbDropDown));
     Settings::DoubleClickBehavior dcb = Settings::instance()->doubleClickBehavior();
     m_doubleClickBehavior->setCurrentIndex(static_cast<int>(dcb));
@@ -174,6 +180,14 @@ SettingsDialog::SettingsDialog(QWidget *parent)
         Settings::instance()->setLoopGallery(state == Qt::Checked);
     });
 
+    connect(m_autoLongImageMode, &QCHECKBOX_CHECKSTATECHANGED, this, [ = ](QT_CHECKSTATE state){
+        Settings::instance()->setAutoLongImageMode(state == Qt::Checked);
+    });
+
+    connect(m_svgTiny12Only, &QCHECKBOX_CHECKSTATECHANGED, this, [ = ](QT_CHECKSTATE state){
+        Settings::instance()->setSvgTiny12Only(state == Qt::Checked);
+    });
+
     connect(m_doubleClickBehavior, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [ = ](int index){
         Settings::instance()->setDoubleClickBehavior(_dc_options.at(index).first);
     });
