@@ -178,8 +178,8 @@
 <context>
     <name>GraphicsScene</name>
     <message>
-        <location filename="../mainwindow.cpp" line="276"/>
-        <location filename="../graphicsscene.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="292"/>
+        <location filename="../graphicsscene.cpp" line="102"/>
         <source>Drag image here</source>
         <translation>Sleep een afbeelding hierheen</translation>
     </message>
@@ -191,13 +191,14 @@
         <translation type="vanished">De bestandspadlijst is leeg</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="50"/>
+        <location filename="../graphicsview.cpp" line="51"/>
         <source>File is not a valid image</source>
         <translation>Het bestand is geen afbeelding</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="54"/>
-        <location filename="../graphicsview.cpp" line="58"/>
+        <location filename="../graphicsview.cpp" line="55"/>
+        <location filename="../graphicsview.cpp" line="60"/>
+        <location filename="../graphicsview.cpp" line="71"/>
         <source>Image data is invalid or currently unsupported</source>
         <translation>De afbeeldingsgegevens zijn beschadigd of worden niet ondersteund</translation>
     </message>
@@ -213,189 +214,194 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="181"/>
-        <location filename="../mainwindow.cpp" line="545"/>
+        <location filename="../mainwindow.cpp" line="190"/>
+        <location filename="../mainwindow.cpp" line="561"/>
         <source>File url list is empty</source>
         <translation>De bestandspadlijst is leeg</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="445"/>
+        <location filename="../mainwindow.cpp" line="461"/>
         <source>&amp;Copy</source>
         <translation>&amp;Kopiëren</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="553"/>
+        <location filename="../mainwindow.cpp" line="569"/>
         <source>Image data is invalid</source>
         <translation>Beschadigde afbeeldingsgegevens</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="560"/>
+        <location filename="../mainwindow.cpp" line="576"/>
         <source>Not supported mimedata: %1</source>
         <translation>Niet-ondersteunde mime-gegevens: %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="759"/>
+        <location filename="../mainwindow.cpp" line="783"/>
         <source>Image From Clipboard</source>
         <translation>Afbeelding van klembord</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="777"/>
+        <location filename="../mainwindow.cpp" line="801"/>
         <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
         <translation>Weet u zeker dat u “%1” naar de prullenbak wilt verplaatsen?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="781"/>
+        <location filename="../mainwindow.cpp" line="805"/>
         <source>Failed to move file to trash</source>
         <translation>Verplaatsen naar prullenbak mislukt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="782"/>
+        <location filename="../mainwindow.cpp" line="806"/>
         <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
         <translation>Het bestand kan niet naar de prullenbak worden verplaatst, mogelijk door een rechtenprobleem of systeembeperking.</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="114"/>
+        <location filename="../actionmanager.cpp" line="106"/>
         <source>Copy P&amp;ixmap</source>
         <translation>P&amp;ixmap kopiëren</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="115"/>
+        <location filename="../actionmanager.cpp" line="107"/>
         <source>Copy &amp;File Path</source>
         <translation>&amp;Bestandspad kopiëren</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="133"/>
+        <location filename="../actionmanager.cpp" line="125"/>
         <source>Properties</source>
         <translation>Eigenschappen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="118"/>
+        <location filename="../actionmanager.cpp" line="110"/>
         <location filename="../aboutdialog.cpp" line="41"/>
         <source>Stay on top</source>
         <translation>Altijd bovenop</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="119"/>
+        <location filename="../actionmanager.cpp" line="111"/>
         <location filename="../aboutdialog.cpp" line="44"/>
         <source>Protected mode</source>
         <translation>Beschermde modus</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="120"/>
+        <location filename="../actionmanager.cpp" line="112"/>
         <location filename="../aboutdialog.cpp" line="47"/>
         <source>Keep transformation</source>
         <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
         <translation>Bewerkingen onthouden</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="99"/>
+        <location filename="../actionmanager.cpp" line="90"/>
         <source>Zoom in</source>
         <translation>Inzoomen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="100"/>
+        <location filename="../actionmanager.cpp" line="91"/>
         <source>Zoom out</source>
         <translation>Uitzoomen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="108"/>
+        <location filename="../actionmanager.cpp" line="99"/>
         <source>Pause/Resume Animation</source>
         <translation>Animatie pauzeren/hervatten</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="109"/>
+        <location filename="../actionmanager.cpp" line="100"/>
         <source>Animation Go to Next Frame</source>
         <translation>Ga naar volgend animatieframe</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="111"/>
+        <location filename="../actionmanager.cpp" line="102"/>
         <source>Flip &amp;Horizontally</source>
         <translation>&amp;Horizontaal spiegelen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="112"/>
+        <location filename="../actionmanager.cpp" line="103"/>
         <source>Fit to view</source>
         <translation>Inpassen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="113"/>
+        <location filename="../actionmanager.cpp" line="104"/>
         <source>Fit to width</source>
         <translation>Aanpassen aan breedte</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="116"/>
+        <location filename="../actionmanager.cpp" line="105"/>
+        <source>Fit long image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="108"/>
         <source>&amp;Paste</source>
         <translation>&amp;Plakken</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="101"/>
+        <location filename="../actionmanager.cpp" line="92"/>
         <source>Toggle Checkerboard</source>
         <translation>Schaakbordpatroon aan/uit</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="95"/>
+        <location filename="../actionmanager.cpp" line="86"/>
         <source>&amp;Open...</source>
         <translation>&amp;Openen…</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="97"/>
+        <location filename="../actionmanager.cpp" line="88"/>
         <source>Actual size</source>
         <translation>Ware grootte</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="98"/>
+        <location filename="../actionmanager.cpp" line="89"/>
         <source>Toggle maximize</source>
         <translation>Maximaliseren aan/uit</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="102"/>
+        <location filename="../actionmanager.cpp" line="93"/>
         <source>Rotate right</source>
         <translation>Naar rechts draaien</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="103"/>
+        <location filename="../actionmanager.cpp" line="94"/>
         <source>Rotate left</source>
         <translation>Naar links draaien</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="105"/>
+        <location filename="../actionmanager.cpp" line="96"/>
         <source>Previous image</source>
         <translation>Vorige afbeelding</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="106"/>
+        <location filename="../actionmanager.cpp" line="97"/>
         <source>Next image</source>
         <translation>Volgende afbeelding</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="776"/>
-        <location filename="../actionmanager.cpp" line="117"/>
+        <location filename="../mainwindow.cpp" line="800"/>
+        <location filename="../actionmanager.cpp" line="109"/>
         <source>Move to Trash</source>
         <translation>Verplaatsen naar prullenbak</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="121"/>
+        <location filename="../actionmanager.cpp" line="113"/>
         <source>Configure...</source>
         <translation>Instellen...</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="122"/>
+        <location filename="../actionmanager.cpp" line="114"/>
         <source>Help</source>
         <translation>Hulp</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="125"/>
+        <location filename="../actionmanager.cpp" line="117"/>
         <source>Show in File Explorer</source>
         <comment>File Explorer is the name of explorer.exe under Windows</comment>
         <translation>Tonen in bestandsbeheer</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="131"/>
+        <location filename="../actionmanager.cpp" line="123"/>
         <source>Show in directory</source>
         <translation>Tonen in map</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="134"/>
+        <location filename="../actionmanager.cpp" line="126"/>
         <source>Quit</source>
         <translation>Afsluiten</translation>
     </message>
@@ -726,141 +732,151 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.cpp" line="31"/>
+        <location filename="../settingsdialog.cpp" line="33"/>
         <source>Settings</source>
         <translation>Instellingen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="39"/>
+        <location filename="../settingsdialog.cpp" line="41"/>
         <source>Options</source>
         <translation>Opties</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="51"/>
+        <location filename="../settingsdialog.cpp" line="53"/>
         <source>Shortcuts</source>
         <translation>Sneltoetsen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="61"/>
+        <location filename="../settingsdialog.cpp" line="63"/>
         <source>Editing shortcuts for action &quot;%1&quot;:</source>
         <translation>Bewerken van sneltoetsen voor actie ‘%1’:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="70"/>
+        <location filename="../settingsdialog.cpp" line="72"/>
         <source>Failed to set shortcuts</source>
         <translation>Instellen mislukt</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="71"/>
+        <location filename="../settingsdialog.cpp" line="73"/>
         <source>Please check if shortcuts are duplicated with existing shortcuts.</source>
         <translation>Controleer of de gekozen sneltoetsen niet al in gebruik zijn.</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="78"/>
+        <location filename="../settingsdialog.cpp" line="80"/>
         <source>Do nothing</source>
         <translation>Niets doen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="79"/>
+        <location filename="../settingsdialog.cpp" line="81"/>
         <source>Close the window</source>
         <translation>Venster sluiten</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="80"/>
+        <location filename="../settingsdialog.cpp" line="82"/>
         <source>Toggle maximize</source>
         <translation>Maximaliseren/Demaximaliseren</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="81"/>
+        <location filename="../settingsdialog.cpp" line="83"/>
         <source>Toggle fullscreen</source>
         <translation>Schermvullende weergave aan/uit</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="85"/>
+        <location filename="../settingsdialog.cpp" line="87"/>
         <source>Zoom in and out</source>
         <translation>In-/Uitzoomen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="86"/>
+        <location filename="../settingsdialog.cpp" line="88"/>
         <source>View next or previous item</source>
         <translation>Ga naar volgende of vorige item</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="90"/>
+        <location filename="../settingsdialog.cpp" line="92"/>
         <source>Auto size</source>
         <translation>Automatische grootte</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="91"/>
+        <location filename="../settingsdialog.cpp" line="93"/>
         <source>Maximized</source>
         <translation>Gemaximaliseerd</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="92"/>
+        <location filename="../settingsdialog.cpp" line="94"/>
         <source>Windowed</source>
         <translation>Venster</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="96"/>
+        <location filename="../settingsdialog.cpp" line="98"/>
         <source>Round (Integer scaling)</source>
         <comment>This option means round up for .5 and above</comment>
         <translation>Rond (geheel getal)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="97"/>
+        <location filename="../settingsdialog.cpp" line="99"/>
         <source>Ceil (Integer scaling)</source>
         <comment>This option means always round up</comment>
         <translation>Keil (geheel getal)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="98"/>
+        <location filename="../settingsdialog.cpp" line="100"/>
         <source>Floor (Integer scaling)</source>
         <comment>This option means always round down</comment>
         <translation>Grond (geheel getal)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="99"/>
+        <location filename="../settingsdialog.cpp" line="101"/>
         <source>Follow system (Fractional scaling)</source>
         <comment>This option means don&apos;t round</comment>
         <translation>Systeeminstelling (fractionele schaal)</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="122"/>
+        <location filename="../settingsdialog.cpp" line="124"/>
         <source>Stay on top when start-up</source>
         <translation>Automatisch altijd bovenop</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="123"/>
+        <location filename="../settingsdialog.cpp" line="125"/>
         <source>Use built-in close window animation</source>
         <translation>Meegeleverde animatie voor venster sluiten gebruiken</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="124"/>
+        <location filename="../settingsdialog.cpp" line="126"/>
         <source>Use light-color checkerboard</source>
         <translation>Licht schaakbordpatroon gebruiken</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="125"/>
+        <location filename="../settingsdialog.cpp" line="127"/>
         <source>Loop the loaded gallery</source>
         <translation>Gekozen galerij herhalen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="126"/>
+        <location filename="../settingsdialog.cpp" line="128"/>
+        <source>Auto long image mode</source>
+        <translation>Automatische langeafbeeldingsmodus</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="129"/>
+        <source>Limit SVG support to SVG Tiny 1.2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="130"/>
         <source>Double-click behavior</source>
         <translation>Dubbelklikgedrag</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="127"/>
+        <location filename="../settingsdialog.cpp" line="131"/>
         <source>Mouse wheel behavior</source>
         <translation>Scrollwielgedrag</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="128"/>
+        <location filename="../settingsdialog.cpp" line="132"/>
         <source>Default window size</source>
         <translation>Standaard vensterafmetingen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="129"/>
+        <location filename="../settingsdialog.cpp" line="133"/>
         <source>HiDPI scale factor rounding policy</source>
         <translation>HiDPI-schaalfactor - afrondbeleid</translation>
     </message>
@@ -868,7 +884,7 @@
 <context>
     <name>ShortcutEdit</name>
     <message>
-        <location filename="../shortcutedit.cpp" line="109"/>
+        <location filename="../shortcutedit.cpp" line="104"/>
         <source>No shortcuts</source>
         <translation>Geen sneltoetsen</translation>
     </message>
@@ -876,7 +892,7 @@
 <context>
     <name>ShortcutEditor</name>
     <message>
-        <location filename="../shortcutedit.cpp" line="75"/>
+        <location filename="../shortcutedit.cpp" line="70"/>
         <source>Shortcut #%1</source>
         <translation>Sneltoets #%1</translation>
     </message>
